import Lib
main = basicTest $ defaultConfig { massage = "Basic Test Version 3.0" }
